﻿using System;
using System.Globalization;
using System.Threading;
using Android.Content;
using Android.Runtime;
using Android.Views;
using ELTE.Calculator.Device;
using ELTE.Calculator.Droid.Device;
using Java.Util;
using Xamarin.Forms;

[assembly: Dependency(typeof(AndroidDeviceProperties))]
namespace ELTE.Calculator.Droid.Device
{
    /// <summary>
    /// Eszköztulajdonságok Android plarformra.
    /// </summary>    
    public class AndroidDeviceProperties : IDeviceProperties
    {
        /// <summary>
        /// Tájolás lekérdezése.
        /// </summary>
        public DeviceOrientation DeviceOrientation
        {
            get
            {
                IWindowManager windowManager = Android.App.Application.Context.GetSystemService(Context.WindowService).JavaCast<IWindowManager>();

                SurfaceOrientation rotation = windowManager.DefaultDisplay.Rotation;

                if (rotation == SurfaceOrientation.Rotation90 || rotation == SurfaceOrientation.Rotation270)
                {
                    return DeviceOrientation.Landscape;
                }
                else
                {
                    return DeviceOrientation.Portrait;
                }
            }
        }

        /// <summary>
        /// Aktuális nyelvi környezet lekérdezése.
        /// </summary>
        public CultureInfo GetCurrentCultureInfo()
        {
            String netLanguage = "en";
            Locale androidLocale = Java.Util.Locale.Default;
            netLanguage = AndroidToDotNetLanguage(androidLocale.ToString().Replace("_", "-"));
            CultureInfo cultureInfo = null;
            try
            {
                cultureInfo = new CultureInfo(netLanguage);
            }
            catch (CultureNotFoundException)
            {
                // ha az adott nyelvi környezet nem található, akkor maradunk az angol mellett
                cultureInfo = new CultureInfo("en");
            }

            return cultureInfo;
        }

        /// <summary>
        /// Localizáció beállítása.
        /// </summary>
        /// <param name="cultureInfo">A nyelvi környezet.</param>
        public void SetLocale(CultureInfo cultureInfo)
        {
            Thread.CurrentThread.CurrentCulture = cultureInfo;
            Thread.CurrentThread.CurrentUICulture = cultureInfo;
        }

        /// <summary>
        /// Android nyelv átalakítása .NET nyelvvé.
        /// </summary>
        String AndroidToDotNetLanguage(String androidLanguage)
        {
            // egyes nyelvi kódok nem egyeznek, vagy nincsenek meg .NET-ben, ezért korrigálni kell
            String netLanguage = androidLanguage;
            switch (androidLanguage)
            {
                case "ms-BN":
                case "ms-MY":
                case "ms-SG":
                    netLanguage = "ms";
                    break;
                case "in-ID":
                    netLanguage = "id-ID";
                    break;
                case "gsw-CH":  
                    netLanguage = "de-CH";
                    break;
            }

            return netLanguage;
        }
    }
}
