﻿using System;
using System.Globalization;
using System.Reflection;
using System.Resources;
using ELTE.Calculator.Device;
using Xamarin.Forms;
using Xamarin.Forms.Xaml;

namespace ELTE.Calculator.View
{
    /// <summary>
    /// A felületen fordítást megvalósító kiegészítés típusa.
    /// </summary>
    [ContentProperty("Text")]
    public class TranslateExtension : IMarkupExtension
    {
        private readonly CultureInfo _cultureInfo;
       
        public TranslateExtension()
        {
            // csak iOS és Android plarformon szükséges
            if (Xamarin.Forms.Device.OS == TargetPlatform.iOS || Xamarin.Forms.Device.OS == TargetPlatform.Android)
            {
                _cultureInfo = DependencyService.Get<IDeviceProperties>().GetCurrentCultureInfo();
            }
        }

        /// <summary>
        /// A szöveg lekérdezése, vagy beállítása (ez a fordítandó tulajdonság).
        /// </summary>
        public String Text { get; set; }

        /// <summary>
        /// Érték fordítása.
        /// </summary>
        public Object ProvideValue(IServiceProvider serviceProvider)
        {
            if (Text == null)
                return String.Empty;

            // a megfelelő nyelvi erőforrás betöltése
            ResourceManager manager = new ResourceManager("ELTE.Calculator.Resources.ApplicationText", typeof(TranslateExtension).GetTypeInfo().Assembly);

            // a megfelelő szöveg lekérdezése
            String translation = manager.GetString(Text, _cultureInfo);
            // Windows környezeten automatikusan a megfelelő nyelvi környezet töltődik be

            // amennyiben van adott nyelvi megfelelő, azt adjuk vissza
            return translation != null ? translation : Text;
        }
    }
}
